@@ -1,7 +1,5 @@
-#' @importFrom lme4 ranef
 #' @importFrom purrr map map_df map2
 #' @importFrom stats qnorm
-#' @importFrom forcats fct_reorder
 #' @importFrom dplyr if_else
 #' @importFrom sjmisc remove_var
 #' @importFrom insight find_random
@@ -34,6 +32,13 @@ plot_type_ranef <- function(model,
     ci.lvl <- NA
   }
 
+  if (!requireNamespace("lme4", quietly = TRUE)) {
+    stop("Package 'lme4' required for this function to work, please install it.")
+  }
+  if (!requireNamespace("glmmTMB", quietly = TRUE)) {
+    stop("Package 'glmmTMB' required for this function to work, please install it.")
+  }
+
   # get tidy output of summary ----
 
   if (inherits(model, "glmmTMB"))
@@ -280,7 +285,7 @@ plot_type_ranef <- function(model,
       function(x, y) {
 
         # sort terms
-        x$term <- forcats::fct_reorder(x$term, x$reihe)
+        x$term <- factor(x$term, levels = unique(x$term[order(x$reihe)]))
 
 
         # now we need a named vector, in order
