@@ -20,7 +20,7 @@
 #'    be removed from the output Counterpart to \code{terms}. \code{rm.terms =
 #'    "t_name"} would remove the term \emph{t_name}. Default is \code{NULL}, i.e.
 #'    all terms are used. For factors, levels that should be removed from the plot
-#'    need to be explicitely indicated in square brackets, and match the model's
+#'    need to be explicitly indicated in square brackets, and match the model's
 #'    coefficient names, e.g. \code{rm.terms = "t_name [2,3]"} would remove the terms
 #'    \code{"t_name2"} and \code{"t_name3"} (assuming that the variable \code{t_name}
 #'    was categorical and has at least the factor levels \code{2} and \code{3}).
@@ -92,7 +92,7 @@
 #' @param string.intercept Character vector, used as name for the intercept parameter. Default is \code{"(Intercept)"}.
 #' @param strings Named character vector, as alternative to arguments like \code{string.ci}
 #'    or \code{string.p} etc. The name (lhs) must be one of the string-indicator from
-#'    the forementioned arguments, while the value (rhs) is the string that is used
+#'    the aforementioned arguments, while the value (rhs) is the string that is used
 #'    as column heading. E.g., \code{strings = c(ci = "Conf.Int.", se = "std. Err")}
 #'    would be equivalent to setting \code{string.ci = "Conf.Int.", string.se = "std. Err"}.
 #' @param ci.hyphen Character vector, indicating the hyphen for confidence interval range.
@@ -102,6 +102,7 @@
 #' @param emph.p Logical, if \code{TRUE}, significant p-values are shown bold faced.
 #' @param digits Amount of decimals for estimates
 #' @param digits.p Amount of decimals for p-values
+#' @param digits.re Amount of decimals for random effects part of the summary table.
 #' @param collapse.ci Logical, if \code{FALSE}, the CI values are shown in
 #'    a separate table column.
 #' @param collapse.se Logical, if \code{FALSE}, the SE values are shown in
@@ -116,7 +117,7 @@
 #' @param show.ci50 Logical, if \code{TRUE}, for Bayesian models, a second
 #'    credible interval is added to the table output.
 #' @param bootstrap Logical, if \code{TRUE}, returns bootstrapped estimates..
-#' @param iterations Numeric, number of bootsrap iterations (default is 1000).
+#' @param iterations Numeric, number of bootstrap iterations (default is 1000).
 #' @param seed Numeric, the number of the seed to replicate bootstrapped estimates. If \code{NULL}, uses random seed.
 #' @param show.fstat Logical, if \code{TRUE}, the F-statistics for each model is
 #'    printed in the table summary. This option is not supported by all model types.
@@ -137,12 +138,14 @@
 #'   \code{p.val = "kenward"} (or \code{p.val = "kr"}), computation of p-values
 #'   is based on conditional F-tests with Kenward-Roger approximation for the
 #'   degrees of freedom. \code{p.val = "satterthwaite"} uses Satterthwaite's
-#'   approximation (see \code{\link[parameters]{dof_kenward}} and \code{\link[parameters]{dof_satterthwaite}}
-#'   for details). In the latter cases, use \code{show.df = TRUE} to show the
-#'   approximated degrees of freedom for each coefficient.
+#'   approximation and \code{"ml1"} uses a "m-l-1" heuristic (see
+#'   \code{\link[parameters]{degrees_of_freedom}} for details). Use
+#'   \code{show.df = TRUE} to show the approximated degrees of freedom
+#'   for each coefficient.
 #' @param p.style Character, indicating if p-values should be printed as
-#'   numeric value (\code{"numeric"}), as asterisks (\code{"asterisk"})
-#'   or both (\code{"both"}). May be abbreviated.
+#'   numeric value (\code{"numeric"}), as 'stars' (asterisks) only (\code{"stars"}),
+#'   or scientific (\code{"scientific"}). Scientific and numeric style can be
+#'   combined with "stars", e.g. \code{"numeric_stars"}
 #' @param CSS A \code{\link{list}} with user-defined style-sheet-definitions,
 #'    according to the \href{http://www.w3.org/Style/CSS/}{official CSS syntax}.
 #'    See 'Details' or \href{https://strengejacke.github.io/sjPlot/articles/table_css.html}{this package-vignette}.
@@ -152,8 +155,6 @@
 #' @param use.viewer Logical, if \code{TRUE}, the HTML table is shown in the IDE's
 #'    viewer pane. If \code{FALSE} or no viewer available, the HTML table is
 #'    opened in a web browser.
-#' @param p.adjust Character vector, if not \code{NULL}, indicates the method
-#'   to adjust p-values. See \code{\link[stats]{p.adjust}} for details.
 #'
 #' @inheritParams plot_models
 #' @inheritParams plot_model
@@ -266,7 +267,7 @@ tab_model <- function(
 
   robust = FALSE,
   vcov.fun = NULL,
-  vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5"),
+  vcov.type = c("HC3", "const", "HC", "HC0", "HC1", "HC2", "HC4", "HC4m", "HC5", "CR0", "CR1", "CR1p", "CR1S", "CR2", "CR3"),
   vcov.args = NULL,
 
   string.pred = "Predictors",
@@ -307,9 +308,10 @@ tab_model <- function(
 
   digits = 2,
   digits.p = 3,
+  digits.re = 2,
   emph.p = TRUE,
-  p.val = c("wald", "kenward", "kr", "satterthwaite"),
-  p.style = c("numeric", "asterisk", "both"),
+  p.val = c("wald", "kenward", "kr", "satterthwaite", "ml1", "betwithin"),
+  p.style = c("numeric", "stars", "numeric_stars", "scientific", "scientific_stars"),
   p.threshold = c(0.05, 0.01, 0.001),
   p.adjust = NULL,
 
@@ -338,7 +340,7 @@ tab_model <- function(
       case <- NULL
   }
 
-  if (p.style == "asterisk") show.p <- FALSE
+  if (p.style == "stars") show.p <- FALSE
 
   # default robust?
   if (isTRUE(robust)) {
@@ -376,7 +378,7 @@ tab_model <- function(
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.estimate"
 
   copos <- which("std.se" == col.order)
-  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.std.error"
+  if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.se"
 
   copos <- which("std.ci" == col.order)
   if (!sjmisc::is_empty(copos)) col.order[copos] <- "std.conf.int"
@@ -469,10 +471,15 @@ tab_model <- function(
         dplyr::select(-.data$conf.low, -.data$conf.high) %>%
         dplyr::mutate(
           p.stars = get_p_stars(.data$p.value, p.threshold),
-          p.sig = .data$p.value < .05,
-          p.value = sprintf("%.*f", digits.p, .data$p.value)
+          p.sig = .data$p.value < .05
         )
 
+      if (grepl("scientific", p.style)) {
+        dat$p.value <- formatC(dat$p.value, format = "e", digits = digits.p)
+      } else {
+        dat$p.value <- sprintf("%.*f", digits.p, dat$p.value)
+      }
+
 
       # emphasize p-values ----
 
@@ -520,6 +527,7 @@ tab_model <- function(
           facets = FALSE,
           show.zeroinf = show.zeroinf,
           p.val = p.val,
+          p_adjust = p.adjust,
           standardize = std_method,
           bootstrap = bootstrap,
           iterations = iterations,
@@ -547,7 +555,7 @@ tab_model <- function(
 
       # add asterisks to estimates ----
 
-      if (p.style %in% c("asterisk", "both")) {
+      if (grepl("stars", p.style)) {
         if (obj_has_name(dat, "estimate"))
           dat$estimate <- sprintf("%.*f <sup>%s</sup>", digits, dat$estimate, dat$p.stars)
         if (!show.est && obj_has_name(dat, "std.estimate"))
@@ -1174,7 +1182,7 @@ tab_model <- function(
   })
 
 
-  if (p.style %in% c("asterisk", "both"))
+  if (grepl("stars", p.style))
     footnote <- sprintf(
       "* p&lt;%s&nbsp;&nbsp;&nbsp;** p&lt;%s&nbsp;&nbsp;&nbsp;*** p&lt;%s",
       format(p.threshold[1]),
@@ -1207,7 +1215,8 @@ tab_model <- function(
     CSS = CSS,
     file = file,
     use.viewer = use.viewer,
-    footnote = footnote
+    footnote = footnote,
+    digits.re = digits.re
   )
 }
 
